import { EllipsisOutlined, PlusOutlined } from '@ant-design/icons';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import { ProTable, TableDropdown, PageContainer } from '@ant-design/pro-components';
import { Button, Dropdown, Space, Tag } from 'antd';
import { useRef } from 'react';
export const waitTimePromise = async (time: number = 100) => {
  return new Promise((resolve) => {
    setTimeout(() => {
      resolve(true);
    }, time);
  });
};

export const waitTime = async (time: number = 100) => {
  await waitTimePromise(time);
};

type GithubIssueItem = {
  url: string;
  id: number;
  number: number;
  title: string;
  labels: {
    name: string;
    color: string;
  }[];
  state: string;
  comments: number;
  created_at: string;
  updated_at: string;
  closed_at?: string;
};

const columns: ProColumns<GithubIssueItem>[] = [
  {
    dataIndex: 'index',
    valueType: 'indexBorder',
    width: 48,
  },
  {
    title: '标题',
    dataIndex: 'title',
    hideInSearch: true
  },
  {
    disable: true,
    title: '状态',
    dataIndex: 'state',
  },
  {
    disable: true,
    title: '标签',
    dataIndex: 'labels',
  },
  {
    title: '创建时间',
    key: 'showTime',
    dataIndex: 'created_at',
  },
  {
    title: '创建时间',
    dataIndex: 'created_at',
    valueType: 'dateRange',
   
  },
  {
    title: '操作',
    valueType: 'option',
    key: 'option',
    render: (text, record, _, action) => [
      <a
        key="editable"
        onClick={() => {
          action?.startEditable?.(record.id);
        }}
      >
        编辑
      </a>,
      <a href={record.url} target="_blank" rel="noopener noreferrer" key="view">
        查看
      </a>,
      <TableDropdown
        key="actionGroup"
        onSelect={() => action?.reload()}
        menus={[
          { key: 'copy', name: '复制' },
          { key: 'delete', name: '删除' },
        ]}
      />,
    ],
  },
];

export default () => {
  const actionRef = useRef<ActionType>();
  return (
    <>
    <PageContainer>
    <ProTable

      columns={columns}
      search={{title: false}}
      pagination={{
        pageSize: 5,
        onChange: (page) => console.log(page),
      }}
      toolBarRender={() => [
        <Button
          key="button"
          type="primary"
        >
          新建
        </Button>,
      ]}
    />
        </PageContainer>
    
    </>
    
  );
};