import { EllipsisOutlined, PlusOutlined } from '@ant-design/icons';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import {
    ProTable, TableDropdown, PageContainer, ModalForm, ProForm,
    ProFormDateRangePicker,
    ProFormSelect,
    ProFormText,
} from '@ant-design/pro-components';
import { Button, Dropdown, Space, Tag, Form } from 'antd';
import { useRef, useState } from 'react';
export const waitTimePromise = async (time: number = 100) => {
    return new Promise((resolve) => {
        setTimeout(() => {
            resolve(true);
        }, time);
    });
};

export const waitTime = async (time: number = 100) => {
    await waitTimePromise(time);
};

const columns: ProColumns[] = [
    {
        title: 'ID',
        dataIndex: 'id',
    },
    {
        title: '省份 (社区)',
        dataIndex: 'title',
    },
    {
        title: '上级',
        dataIndex: 'parent_id',
    },
    {
        title: '操作',
        valueType: 'option',
        key: 'option',
        render: (text, record, _, action) => [
            <a
                key="editable"
                onClick={() => {
                    action?.startEditable?.(record.id);
                }}
            >
                编辑
            </a>,
        ],
    },
];

export default () => {
    const [form] = Form.useForm<AreaType.form>();
    const [data, setData] = useState([{ id: 1 }])
    return (
        <>
            <PageContainer>
                <ProTable
                    dataSource={data}
                    columns={columns}
                    pagination={{
                        pageSize: 5,
                        onChange: (page) => console.log(page),
                    }}
                    toolBarRender={() => [
                        <ModalForm<AreaType.form>
                            title="新增地区"
                            trigger={
                                <Button type="primary">
                                    <PlusOutlined />
                                    新建地区
                                </Button>
                            }
                            submitter={{
                                render: (props, defaultDoms) => {
                                    return [
                                        <Button
                                            key="extra-reset"
                                            onClick={() => {
                                                props.reset();
                                            }}
                                        >
                                            重置
                                        </Button>,
                                        ...defaultDoms,
                                    ];
                                },
                            }}
                            form={form}
                            autoFocusFirstInput
                            modalProps={{
                                destroyOnClose: true,
                                onCancel: () => console.log('run'),
                            }}
                            submitTimeout={2000}
                            onFinish={async (values) => {
                                await waitTime(2000);
                                console.log(values.title);
                                return true;
                            }}
                        >
                            <ProFormText
                                name="title"
                                label="地区名称"
                                placeholder="请输入地区名称"
                            />
                            <ProFormSelect
                                name="level_name"
                                label="选择归属地"
                                placeholder="请选择归属地"
                            />
                            <ProFormSelect
                                name="is_community"
                                label="是否是社区"
                                placeholder="请选择是否是社区"
                            />
                        </ModalForm>,
                        <ModalForm<AreaType.form>
                        title="导入街道（镇）"
                        trigger={
                            <Button type="primary">
                                <PlusOutlined />
                                导入街道（镇）
                            </Button>
                        }
                        submitter={{
                            render: (props, defaultDoms) => {
                                return [
                                    <Button
                                        key="extra-reset"
                                        onClick={() => {
                                            props.reset();
                                        }}
                                    >
                                        重置
                                    </Button>,
                                    ...defaultDoms,
                                ];
                            },
                        }}
                        form={form}
                        autoFocusFirstInput
                        modalProps={{
                            destroyOnClose: true,
                            onCancel: () => console.log('run'),
                        }}
                        submitTimeout={2000}
                        onFinish={async (values) => {
                            await waitTime(2000);
                            console.log(values.title);
                            return true;
                        }}
                    >
                        <ProFormText
                            name="title"
                            label="地区名称"
                            placeholder="请输入地区名称"
                        />
                        <ProFormSelect
                            name="level_name"
                            label="选择归属地"
                            placeholder="请选择归属地"
                        />
                        <ProFormSelect
                            name="is_community"
                            label="是否是社区"
                            placeholder="请选择是否是社区"
                        />
                    </ModalForm>
                    ]}
                />
            </PageContainer>

        </>

    );
};

