import { EllipsisOutlined, PlusOutlined } from '@ant-design/icons';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import {
    ProTable, TableDropdown, PageContainer, ModalForm, ProForm,
    ProFormDateRangePicker,
    ProFormSelect,
    ProFormText,
} from '@ant-design/pro-components';
import { Button, Dropdown, Space, Tag, Form } from 'antd';
import { useRef, useState } from 'react';
export const waitTimePromise = async (time: number = 100) => {
    return new Promise((resolve) => {
        setTimeout(() => {
            resolve(true);
        }, time);
    });
};

export const waitTime = async (time: number = 100) => {
    await waitTimePromise(time);
};

const columns: ProColumns[] = [
    {
        title: 'ID',
        dataIndex: 'id',
    },
    {
        title: '部门名称',
        dataIndex: 'title',
    },
    {
        title: '部门等级',
        dataIndex: 'level',
    },
    {
        title: '操作',
        valueType: 'option',
        key: 'option',
        render: (text, record, _, action) => [
            <a
                key="editable"
                onClick={() => {
                    action?.startEditable?.(record.id);
                }}
            >
                编辑
            </a>,
        ],
    },
];

export default () => {
    const [form] = Form.useForm<BaiduType.form>();
    const [data, setData] = useState([{ id: 1 }])
    return (
        <>
            <PageContainer>
                <ProTable
                    dataSource={data}
                    columns={columns}
                    pagination={{
                        pageSize: 5,
                        onChange: (page) => console.log(page),
                    }}
                    toolBarRender={() => [
                        <ModalForm<ProjectType.form>
                            title="新增部门"
                            trigger={
                                <Button type="primary">
                                    <PlusOutlined />
                                    新建表单
                                </Button>
                            }
                            submitter={{
                                render: (props, defaultDoms) => {
                                    return [
                                        <Button
                                            key="extra-reset"
                                            onClick={() => {
                                                props.reset();
                                            }}
                                        >
                                            重置
                                        </Button>,
                                        ...defaultDoms,
                                    ];
                                },
                            }}
                            form={form}
                            autoFocusFirstInput
                            modalProps={{
                                destroyOnClose: true,
                                onCancel: () => console.log('run'),
                            }}
                            submitTimeout={2000}
                            onFinish={async (values) => {
                                await waitTime(2000);
                                console.log(values.name);
                                return true;
                            }}
                        >
                            <ProFormText
                                name="title"
                                label="部门名称"
                                placeholder="请输入部门名称"
                            />
                            <ProFormSelect
                                name="level_name"
                                label="部门等级"
                                placeholder="请选择部门等级"
                            />
                        </ModalForm>
                    ]}
                />
            </PageContainer>

        </>

    );
};