import { EllipsisOutlined, PlusOutlined } from '@ant-design/icons';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import {
    ProTable, TableDropdown, PageContainer, ModalForm, ProForm,
    ProFormDateRangePicker,
    ProFormSelect,
    ProFormText,
} from '@ant-design/pro-components';
import { Button, Dropdown, Space, Tag, Form } from 'antd';
import { useRef, useState } from 'react';
export const waitTimePromise = async (time: number = 100) => {
    return new Promise((resolve) => {
        setTimeout(() => {
            resolve(true);
        }, time);
    });
};

export const waitTime = async (time: number = 100) => {
    await waitTimePromise(time);
};

const columns: ProColumns[] = [
    {
        title: 'ID',
        dataIndex: 'id',
    },
    {
        title: '姓名',
        dataIndex: 'name',
    },
    {
        title: '手机号',
        dataIndex: 'phone',
    },
    {
        title: '工号',
        dataIndex: 'number',
    },
    {
        title: '所属辖区',
        dataIndex: 'station.name',
    },
    {
        title: '所属部门',
        dataIndex: 'department.title',
    },
    {
        title: '审核状态',
        dataIndex: 'state',
        valueEnum: {
            open: {
              text: '待审核',
              status: 'Error',
            },
            closed: {
              text: '已审核',
              status: 'Success',
              disabled: true,
            },
            processing: {
              text: '不通过',
              status: 'Processing',
            },
          },
    },
    {
        title: '门禁图像',
        dataIndex: 'face_image',
    },
    {
        title: '操作',
        valueType: 'option',
        key: 'option',
        render: (text, record, _, action) => [
            <a
                key="editable"
                onClick={() => {
                    action?.startEditable?.(record.id);
                }}
            >
                编辑
            </a>,
        ],
    },
];

export default () => {
    const [form] = Form.useForm<BaiduType.form>();
    const [data, setData] = useState([{ id: 1 }])
    return (
        <>
            <PageContainer>
                <ProTable
                    dataSource={data}
                    columns={columns}
                    pagination={{
                        pageSize: 5,
                        onChange: (page) => console.log(page),
                    }}
                    toolBarRender={() => [
                        <ModalForm<ProjectType.form>
                            title="新增用户信息"
                            trigger={
                                <Button type="primary">
                                    <PlusOutlined />
                                    新建表单
                                </Button>
                            }
                            submitter={{
                                render: (props, defaultDoms) => {
                                    return [
                                        <Button
                                            key="extra-reset"
                                            onClick={() => {
                                                props.reset();
                                            }}
                                        >
                                            重置
                                        </Button>,
                                        ...defaultDoms,
                                    ];
                                },
                            }}
                            form={form}
                            autoFocusFirstInput
                            modalProps={{
                                destroyOnClose: true,
                                onCancel: () => console.log('run'),
                            }}
                            submitTimeout={2000}
                            onFinish={async (values) => {
                                await waitTime(2000);
                                console.log(values.name);
                                return true;
                            }}
                        >
                            <ProFormText
                                name="name"
                                label="用户姓名"
                                placeholder="请输入用户姓名"
                            />
                            <ProFormText
                                name="name"
                                label="联系方式"
                                placeholder="请输入联系方式"
                            />  <ProFormText
                                name="name"
                                label="工号"
                                placeholder="请输入工号"
                            />
                            <ProFormSelect
                                name="aip_id"
                                label="所属辖区"
                                placeholder="请选择所属辖区"
                            />
                            <ProFormSelect
                                name="aip_id"
                                label="所属部门："
                                placeholder="请选择所属部门"
                            />
                        </ModalForm>
                    ]}
                />
            </PageContainer>

        </>

    );
};